@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -38,54 +38,55 @@ class octave_value_list;
 #include "pt-exp.h"
 #include "pt-walk.h"
 
-namespace octave
+OCTAVE_BEGIN_NAMESPACE(octave)
+
+class symbol_scope;
+class tree_argument_list;
+
+// General matrices.  This allows us to construct matrices from
+// other matrices, variables, and functions.
+
+class tree_matrix : public tree_array_list
 {
-  class symbol_scope;
-  class tree_argument_list;
+public:
 
-  // General matrices.  This allows us to construct matrices from
-  // other matrices, variables, and functions.
+  tree_matrix (tree_argument_list *row = nullptr, int l = -1, int c = -1)
+    : tree_array_list (row, l, c)
+  { }
 
-  class tree_matrix : public tree_array_list
+  // No copying!
+
+  tree_matrix (const tree_matrix&) = delete;
+
+  tree_matrix& operator = (const tree_matrix&) = delete;
+
+  ~tree_matrix (void) = default;
+
+  bool is_matrix (void) const { return true; }
+
+  bool rvalue_ok (void) const { return true; }
+
+  tree_expression * dup (symbol_scope& scope) const;
+
+  octave_value evaluate (tree_evaluator&, int nargout = 1);
+
+  octave_value_list evaluate_n (tree_evaluator& tw, int nargout = 1)
   {
-  public:
+    return ovl (evaluate (tw, nargout));
+  }
 
-    tree_matrix (tree_argument_list *row = nullptr, int l = -1, int c = -1)
-      : tree_array_list (row, l, c)
-    { }
+  void accept (tree_walker& tw)
+  {
+    tw.visit_matrix (*this);
+  }
+};
 
-    // No copying!
+extern std::string
+get_concat_class (const std::string& c1, const std::string& c2);
 
-    tree_matrix (const tree_matrix&) = delete;
+extern void
+maybe_warn_string_concat (bool all_dq_strings_p, bool all_sq_strings_p);
 
-    tree_matrix& operator = (const tree_matrix&) = delete;
-
-    ~tree_matrix (void) = default;
-
-    bool is_matrix (void) const { return true; }
-
-    bool rvalue_ok (void) const { return true; }
-
-    tree_expression * dup (symbol_scope& scope) const;
-
-    octave_value evaluate (tree_evaluator&, int nargout = 1);
-
-    octave_value_list evaluate_n (tree_evaluator& tw, int nargout = 1)
-    {
-      return ovl (evaluate (tw, nargout));
-    }
-
-    void accept (tree_walker& tw)
-    {
-      tw.visit_matrix (*this);
-    }
-  };
-
-  extern std::string
-  get_concat_class (const std::string& c1, const std::string& c2);
-
-  extern void
-  maybe_warn_string_concat (bool all_dq_strings_p, bool all_sq_strings_p);
-}
+OCTAVE_END_NAMESPACE(octave)
 
 #endif
