@@ -1,4 +1,9 @@
-## Copyright (C) 2005-2019 John W. Eaton
+########################################################################
+##
+## Copyright (C) 2005-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} clf
@@ -40,21 +47,19 @@
 ## @seealso{cla, close, delete, reset}
 ## @end deftypefn
 
-## Author: jwe
-
 function h = clf (varargin)
 
   if (nargin > 2)
     print_usage ();
   elseif (nargin == 0)
-    hfig = gcf;
+    hfig = gcf ();
     do_reset = false;
   elseif (nargin == 1)
     if (isscalar (varargin{1}) && isfigure (varargin{1}))
       hfig = varargin{1};
       do_reset = false;
     elseif (ischar (varargin{1}) && strcmpi (varargin{1}, "reset"))
-      hfig = gcf;
+      hfig = gcf ();
       do_reset = true;
     else
       print_usage ();
@@ -71,15 +76,28 @@ function h = clf (varargin)
 
   if (do_reset)
     ## Delete all the children, including the ones with hidden handles,
-    ## except default menus.
+    ## except default menus and toolbar.
+
     kids = allchild (hfig);
-    ismenu = cellfun (@(s) strncmp (s, "__default_menu_", 15), ...
-                      get (kids, "tag"));
-    delete (kids(! ismenu));
+
+    if (! isempty (kids))
+      tags = get (kids, "tag");
+      ## It's possible for a figure to have just one child and then get
+      ## will return a single value instead of a cell array.
+      if (! iscell (tags))
+        tags = {tags};
+      endif
+      ismenu = cellfun (@(s) strncmp (s, "__default_menu_", 15), tags);
+      istoolbar = cellfun (@(s) strncmp (s, "__default_toolbar_menu_", 18), tags);
+      delete (kids(! ismenu & ! istoolbar));
+    endif
+
     reset (hfig);
 
-    ## Recover figure listeners which have been deleted
-    __add_default_menu__ (hfig, kids(ismenu));
+    if (! isempty (kids))
+      ## Recover figure listeners which have been deleted
+      __add_default_menu__ (hfig, kids(ismenu), kids(istoolbar));
+    endif
 
     __set_default_mouse_modes__ (hfig);
   else
@@ -101,7 +119,7 @@ endfunction
 %!test
 %! hf = figure ("visible", "off");
 %! unwind_protect
-%!   l = line;
+%!   l = line ();
 %!   assert (! isempty (get (gcf, "children")));
 %!   clf;
 %!   assert (isempty (get (gcf, "children")));
