@@ -1,4 +1,9 @@
-## Copyright (C) 2012-2019 Fotios Kasolis
+########################################################################
+##
+## Copyright (C) 2012-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {@var{z} =} polyeig (@var{C0}, @var{C1}, @dots{}, @var{Cl})
@@ -42,7 +49,7 @@
 
 function [z, v] = polyeig (varargin)
 
-  if (nargin < 1 || nargout > 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -98,8 +105,7 @@ endfunction
 %! assert (norm (d), 0.0);
 
 ## Test input validation
-%!error polyeig ()
-%!error [a,b,c] = polyeig (1)
+%!error <Invalid call> polyeig ()
 %!error <coefficients must be square matrices> polyeig (ones (3,2))
 %!error <coefficients must have the same dimensions>
 %! polyeig (ones (3,3), ones (2,2))
